==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/geometry/RealRectangle2D.hpp <==
#ifndef _COM_SUN_STAR_GEOMETRY_REALRECTANGLE2D_HPP_
#define _COM_SUN_STAR_GEOMETRY_REALRECTANGLE2D_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_GEOMETRY_REALRECTANGLE2D_HDL_
#include "com/sun/star/geometry/RealRectangle2D.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace geometry {

inline RealRectangle2D::RealRectangle2D() SAL_THROW( () )
    : X1(0)
    , Y1(0)
    , X2(0)
    , Y2(0)
{
}

inline RealRectangle2D::RealRectangle2D(const double& X1_, const double& Y1_, const double& X2_, const double& Y2_) SAL_THROW( () )
    : X1(X1_)
    , Y1(Y1_)
    , X2(X2_)
    , Y2(Y2_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::geometry::RealRectangle2D const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.geometry.RealRectangle2D");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_GEOMETRY_REALRECTANGLE2D_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/geometry/RealRectangle2D.hpp <==
#ifndef _COM_SUN_STAR_GEOMETRY_REALRECTANGLE2D_HPP_
#define _COM_SUN_STAR_GEOMETRY_REALRECTANGLE2D_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_GEOMETRY_REALRECTANGLE2D_HDL_
#include "com/sun/star/geometry/RealRectangle2D.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace geometry {

inline RealRectangle2D::RealRectangle2D() SAL_THROW( () )
    : X1(0)
    , Y1(0)
    , X2(0)
    , Y2(0)
{
}

inline RealRectangle2D::RealRectangle2D(const double& X1_, const double& Y1_, const double& X2_, const double& Y2_) SAL_THROW( () )
    : X1(X1_)
    , Y1(Y1_)
    , X2(X2_)
    , Y2(Y2_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace geometry {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::geometry::RealRectangle2D const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.geometry.RealRectangle2D");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::geometry::RealRectangle2D const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::geometry::RealRectangle2D >::get();
}

#endif // _COM_SUN_STAR_GEOMETRY_REALRECTANGLE2D_HPP_
